% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{regresfast}
\alias{regresfast}
\title{Fast linear regressions}
\usage{
regresfast(X, y, covariates, hascovar = FALSE)
}
\arguments{
\item{X}{matrix of voxlels (columns) for all
subjects (rows).}

\item{y}{vector of behavioral scores.}

\item{covariates}{matrix with one or more columns.
Must be of same length as behavior. This variable
should always be set, and the next argument can tell
if covariates should be used or not.}

\item{hascovar}{logical to tell whether covariates
should be used.}
}
\value{
List with:
\itemize{
\item\code{statistic} - regression t-score
\item\code{n} - number of subjects
\item\code{kxfm} - degrees of freedom.
}
}
\description{
Takes a matrix of voxels and a vector of behavior
and runs fast regressions for each voxel. Covariates
can be defined (i.e. age) to find the effect of each
voxel on behavior within the context of other predictive
factors.
}
\examples{
set.seed(1234)
lesmat = matrix(rbinom(40,1,0.2), ncol=2)
set.seed(1234)
behavior = rnorm(20)
test = LESYMAP::regresfast(lesmat, behavior, as.matrix(behavior), hascovar=FALSE)
test$statistic[,1] # 0.6915683 1.1434760
test$kxmat # 2

}
\author{
Dorian Pustina
}
